Logging status of hipCtxSynchronize was missing
Test if hip profiling is active for MARKER_END in ihipPostLaunchKernel
Add MARKER_END after the completion of a kernel launched through
the "grid launch"
Этот коммит содержится в:
Pierre
2017-11-13 16:13:19 -05:00
родитель 85975e719d
Коммит 6baaed8e48
3 изменённых файлов: 7 добавлений и 2 удалений
+3
Просмотреть файл
@@ -92,5 +92,8 @@ namespace hip_impl
delete static_cast<L*>(locked_stream);
locked_stream = nullptr;
if(HIP_PROFILE_API) {
MARKER_END();
}
}
}
+1 -1
Просмотреть файл
@@ -269,7 +269,7 @@ hipError_t hipCtxGetSharedMemConfig ( hipSharedMemConfig * pConfig )
hipError_t hipCtxSynchronize ( void )
{
HIP_INIT_API(1);
return ihipSynchronize(); //TODP Shall check validity of ctx?
return ihipLogStatus(ihipSynchronize()); //TODP Shall check validity of ctx?
}
hipError_t hipCtxGetFlags ( unsigned int* flags )
+3 -1
Просмотреть файл
@@ -1592,7 +1592,9 @@ void ihipPostLaunchKernel(const char *kernelName, hipStream_t stream, grid_launc
tprintf(DB_SYNC, "ihipPostLaunchKernel, unlocking stream\n");
stream->lockclose_postKernelCommand(kernelName, lp.av);
MARKER_END();
if(HIP_PROFILE_API) {
MARKER_END();
}
}
//=================================================================================================